(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@rhi-ui/html')) :
    typeof define === 'function' && define.amd ? define(['exports', '@rhi-ui/html'], factory) :
    (factory((global.RHI_UI_MARKDOWN_VIEWER = {}),global.RHI_UI_HTML));
}(this, (function (exports,html) { 'use strict';

    class RhiUiMarkdownViewer extends HTMLElement {
        constructor() {
            super();
            this.props = {};
            this.attachShadow({ mode: 'open' });
            const props = RhiUiMarkdownViewer.properties;
            for (let key in props) {
                this.props[key] = props[key].value;
            }
            this.requestRender();
        }
        static get is() { return 'rhi-ui-markdown-viewer'; }
        getTemplate(props) {
            return html.html `
            <!-- shadow DOM for your element -->
            <!-- RHI Blue: #007DC2 -->
            <style>
                :host {
                    display: block;
                    white-space: normal;
                }

                pre {
                    overflow-x: auto;
                    padding-bottom: 16px;
                }

                table {
                    font-size: 14px;
                }

                table td,
                table th {
                    padding: 4px 8px;
                }
            </style>
            <div id="markdown">Loading file...</div>
        `;
        }
        static get properties() {
            return {
                'file-uri': {
                    type: String,
                    value: ''
                }
            };
        }
        static get observedAttributes() {
            const attributes = [];
            for (let key in RhiUiMarkdownViewer.properties) {
                attributes.push(key.toLowerCase());
            }
            return attributes;
        }
        attributeChangedCallback(name, oldValue, newValue, namespace) {
            if (oldValue === newValue) {
                return;
            }
            this.props[name] = newValue;
            if (name === 'file-uri' && newValue) {
                this.loadMarkdown(newValue)
                    .then((content) => this.updateReadme(content));
            }
        }
        requestRender() {
            const template = document.createElement('template');
            template.innerHTML = this.getTemplate({});
            this.shadowRoot.appendChild(template.content.cloneNode(true));
        }
        loadMarkdown(fileUri) {
            return new Promise((resolve, reject) => {
                const request = new XMLHttpRequest();
                request.open('GET', fileUri, true);
                request.onload = function (e) {
                    if (request.readyState === 4) {
                        if (request.status === 200) {
                            resolve(request.responseText);
                        }
                    }
                };
                request.onerror = function (e) {
                    reject(request.statusText);
                };
                request.send(null);
            });
        }
        updateReadme(content) {
            const md = window['markdownit']();
            if (!md) {
                throw `${RhiUiMarkdownViewer.is} :: updateReadme :: 'markdownid' is not loaded.  Make sure to include the the file: <script src="../node_modules/markdown-it/dist/markdown-it.min.js"></script>`;
            }
            this.shadowRoot.getElementById('markdown').innerHTML = md.render(content);
        }
    }
    customElements.define(RhiUiMarkdownViewer.is, RhiUiMarkdownViewer);

    exports.RhiUiMarkdownViewer = RhiUiMarkdownViewer;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
